@@ -3,14 +3,14 @@ from Microsoft.Finance.DataStandards.UnitTest.TestCase.DimensionTestCase import
 from Microsoft.Finance.DataStandards.UnitTest.TestSuite.BaseTestSuite import BaseTestSuite
 from pyspark.sql.session import SparkSession
 
-class TestSuiteDimension(BaseTestSuite):
+class DimensionTestSuite(BaseTestSuite):
 
     def __init__(self, sparkSession: SparkSession, databaseName: str, tableName: str) -> None:
-        super(TestSuiteDimension, self).__init__(sparkSession, databaseName, tableName)
+        super(DimensionTestSuite, self).__init__(sparkSession, databaseName, tableName)
 
     def queue_tests(self) -> None:
-        dimensionTestCase = TestCaseDimension(self.SparkSession, self.FieldInfo, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents)
-        commonTestCase = TestCaseCommon(self.TableDataFrame, self.FieldInfo, self.CustomEvents)
+        dimensionTestCase = DimensionTestCase(self.SparkSession, self.FieldInfo, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents)
+        commonTestCase = CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents)
         self.TestSuite.addTest(dimensionTestCase)
         self.TestSuite.addTest(commonTestCase)
 
